FreeBSD/ports 72c206cdevel/py-tzdata Makefile distinfo

devel/py-tzdata: Update to 2026.4

Approved by:    kai (maintainer via email)
DeltaFile
+3-3devel/py-tzdata/distinfo
+1-1devel/py-tzdata/Makefile
+4-42 files

FreeBSD/ports 61cd62atextproc/py-zensical Makefile distinfo

textproc/py-zensical: Update to 0.0.62

Approved by:    kai (maintainer via email)
DeltaFile
+3-3textproc/py-zensical/distinfo
+1-1textproc/py-zensical/Makefile
+4-42 files

LLVM/project da57c79clang/lib/StaticAnalyzer/Core CallEvent.cpp

[analyzer][NFC] Determine object parameter constness for getExtraInvalidatedValues
DeltaFile
+11-1clang/lib/StaticAnalyzer/Core/CallEvent.cpp
+11-11 files

FreeBSD/ports 0a61592security/vuxml/vuln 2026.xml

security/vuxml: Document multiple strongSwan vulnerabilities

PR:             298372
Sponsored by:   Rubicon Communications, LLC ("Netgate")
DeltaFile
+78-0security/vuxml/vuln/2026.xml
+78-01 files

FreeBSD/src 416611fsys/cam/nvme nvme_da.c, sys/dev/nvme nvme_ns.c

nvme: reject namespaces formatted with metadata

The active LBA format's MS field was never examined. I/O to a
metadata-formatted namespace carries neither interleaved metadata
nor MPTR, so every command is malformed, yet the namespace attaches
as a disk with the wrong sector size.

Reviewed by:    imp, adrian
Differential Revision:  https://reviews.freebsd.org/D59625
DeltaFile
+9-0sys/dev/nvme/nvme_ns.c
+9-0sys/cam/nvme/nvme_da.c
+18-02 files

FreeBSD/ports 57d4f61science/py-tensorflow distinfo Makefile, science/py-tensorflow/files bazelrc

science/py-tensorflow: Fix build

It was broken since with the last update of jsoncpp
its headers were pushed into include/jsoncpp.

Reported by:    fallout
DeltaFile
+9-5science/py-tensorflow/Makefile
+10-1science/py-tensorflow/files/freebsd/cc_toolchain_config.bzl
+2-0science/py-tensorflow/files/bazelrc
+0-1science/py-tensorflow/distinfo
+21-74 files

LLVM/project eb5c148llvm/lib/CodeGen MachineScheduler.cpp, llvm/test/CodeGen/AArch64 cluster-frame-index.mir

[MachineScheduler] Order fixed-FI memory operations by object offset (#219669)

## Summary

- sort fixed frame-index memory operands by their explicit stack offsets
- preserve the existing frame-index ordering for ordinary stack objects
and as a tie-breaker
- add an AArch64 MIR regression with fixed objects created out of offset
order

## Background

`BaseMemOpClusterMutation` currently orders frame-index bases by
frame-index number, adjusted for the stack growth direction. Fixed frame
objects are different from ordinary stack objects: they carry explicit
offsets, and their creation order is not required to match address
order.

As a result, a target clustering hook can receive two fixed objects in

    [22 lines not shown]
DeltaFile
+49-0llvm/test/CodeGen/AArch64/cluster-frame-index.mir
+19-0llvm/lib/CodeGen/MachineScheduler.cpp
+68-02 files

FreeBSD/ports 28b521dsecurity/strongswan Makefile pkg-plist, security/strongswan/files patch-conf_Makefile.in patch-src_libcharon_plugins_smp_smp.c

security/strongswan: Update 6.0.7 => 6.1.0

Changelog:
https://github.com/strongswan/strongswan/releases/tag/6.1.0

PR:             298372
MFH:            2026Q3
Security:       CVE-2026-78123
Security:       CVE-2026-78124
Security:       CVE-2026-78126
Security:       CVE-2026-78127
Security:       CVE-2026-78129
Security:       CVE-2026-78130
Security:       CVE-2026-78131
Security:       CVE-2026-78132
Security:       CVE-2026-78133
Security:       CVE-2026-78134
Security:       CVE-2026-78135
Sponsored by:   Rubicon Communications, LLC ("Netgate")

    [2 lines not shown]
DeltaFile
+0-23security/strongswan/files/patch-src_libcharon_plugins_smp_smp.c
+3-3security/strongswan/distinfo
+0-5security/strongswan/pkg-plist
+2-2security/strongswan/files/patch-conf_Makefile.in
+2-2security/strongswan/Makefile
+7-355 files

NetBSD/pkgsrc IQuBi11doc CHANGES-2026 TODO

   doc: Updated net/arti to 2.6.0
VersionDeltaFile
1.27922+3-3doc/TODO
1.6100+2-1doc/CHANGES-2026
+5-42 files

NetBSD/pkgsrc wieSdaCnet/arti Makefile cargo-depends.mk

   arti: update to 2.6.0.

   (leaf package)

   Arti 2.6.0 continues our steady progress on relay and directory
   authority development, including on document parsing, directory
   mirror support, and DNS stream handling.

   Additionally, this release makes Congestion control and Counter
   Galois Onion cryptography always on in `arti`.

   As usual, there are also many under-the-hood improvements and bug
   fixes.
VersionDeltaFile
1.20+343-376net/arti/distinfo
1.20+113-124net/arti/cargo-depends.mk
1.25+2-2net/arti/Makefile
+458-5023 files

OpenBSD/src jzmrHRflibexec/ld.so resolve.h boot.c, libexec/ld.so/hppa boot_md.c

   Use the aux-args-located AUX_openbsd_execpath entry provided by
   execve(2) as $ORIGIN for requests from the main executable dso (if
   available, otherwise attempt to use the old realpath mechanism).  The
   ld.so bootstrapping parses the AUX_* array into a 10-entry dl_data[]
   for the post-relocation code to inspect easier.  Index 0 was not being
   used, so use it to pass the auxval pointer to the bootstrap code.  In
   the bootstrap code we make a copy of the execpath string to avoid later
   $ORIGIN expansions in ld.so looking at possibly (intentionally?) damaged
   stack.
   ok kettenis kurt
VersionDeltaFile
1.224+21-1libexec/ld.so/loader.c
1.104+14-7libexec/ld.so/resolve.c
1.5+7-5libexec/ld.so/mips64/boot_md.c
1.7+7-5libexec/ld.so/hppa/boot_md.c
1.20+7-5libexec/ld.so/boot.c
1.109+2-1libexec/ld.so/resolve.h
+58-246 files

FreeBSD/ports 5a7f758security/strongswan pkg-plist Makefile, security/strongswan/files patch-conf_Makefile.in patch-src_libcharon_plugins_smp_smp.c

security/strongswan: Update 6.0.7 => 6.1.0

Changelog:
https://github.com/strongswan/strongswan/releases/tag/6.1.0

PR:             298372
MFH:            2026Q3
Security:       CVE-2026-78123
Security:       CVE-2026-78124
Security:       CVE-2026-78126
Security:       CVE-2026-78127
Security:       CVE-2026-78129
Security:       CVE-2026-78130
Security:       CVE-2026-78131
Security:       CVE-2026-78132
Security:       CVE-2026-78133
Security:       CVE-2026-78134
Security:       CVE-2026-78135
Sponsored by:   Rubicon Communications, LLC ("Netgate")
DeltaFile
+0-23security/strongswan/files/patch-src_libcharon_plugins_smp_smp.c
+3-3security/strongswan/distinfo
+0-5security/strongswan/pkg-plist
+2-3security/strongswan/Makefile
+2-2security/strongswan/files/patch-conf_Makefile.in
+7-365 files

Linux/linux 2209876include/linux ring_buffer.h, kernel fork.c

Merge tag 'trace-v7.3-rc2' of git://git.kernel.org/pub/scm/linux/kernel/git/trace/linux-trace

Pull tracing fixes from Steven Rostedt:

 - Don't destroy user event fields when removal fails

   User event fields are destroyed before the event is removed from
   visibility. But that can fail leaving the still visible event with no
   fields. Move the destroying of the fields to after the event is
   successfully removed from visibility.

 - Initialize function graph state is fork before calling
   copy_exec_state()

   For non-CLONE_VM forks, copy_exec_state() allocates a new
   task_exec_state. If that allocation fails, ftrace_graph_exit_task()
   will free the tasks ret_stack pointer. Since that pointer is still
   using the parent's ret_stack, it mistakenly frees the parent's
   pointer too.

    [169 lines not shown]
DeltaFile
+45-41kernel/trace/trace_events_hist.c
+45-1kernel/trace/trace.c
+20-6kernel/trace/trace_events_user.c
+15-8kernel/trace/ring_buffer.c
+17-2include/linux/ring_buffer.h
+5-2kernel/fork.c
+147-609 files not shown
+165-6815 files

FreeBSD/ports 2a88a73x11-fm/thunar Makefile distinfo

x11-fm/thunar: Update to 4.20.10
DeltaFile
+3-3x11-fm/thunar/distinfo
+1-1x11-fm/thunar/Makefile
+4-42 files

LLVM/project 8d2fef4

Merge branch 'users/ziqingluo/PR-187125348-3' of github.com:llvm/llvm-project into users/ziqingluo/PR-187125348-3

 Conflicts:
        clang/lib/ScalableStaticAnalysis/Analyses/PointerFlow/PointerFlowExtractor.cpp
        clang/lib/ScalableStaticAnalysis/SourceTransformation/Transformations/CppBoundedBuffers.cpp
DeltaFile
+0-00 files

LLVM/project 9a7259dclang/lib/ScalableStaticAnalysis/SourceTransformation CMakeLists.txt, clang/lib/ScalableStaticAnalysis/SourceTransformation/Transformations CppBoundedBuffers.cpp

[SSAF][clang-reforge] Retrofit expressions after CppBoundedBuffers decl rewrites

PR #210457 introduces declaration rewriting.  When CppBoundedBuffers
rewrites a declaration or return type to a bounded_ptr/bounded_array,
some of the existing uses of that entity needs retrofit.

This commit creates expression rewrites for the following patterns:

- Append '.data()' to call arguments when necessary parameter is not
  transformed but argument is transformed.
- Append '.as_bounded<T>()' to call arguments when both parameter and
  argument are transformed but element types are not identical.
- Rewrite '&e[i]' to '(e + i)' and '&*e'/'&(*e)' to 'e', if 'e' is
  transformed.
- Rewrite '(T*)e', 'static_cast<T*>(e)', and 'reinterpret_cast<T*>(e)'
  to 'e.as_bounded<T>()', if 'e' is transformed.

The 3rd step of
rdar://187125348
DeltaFile
+445-5clang/lib/ScalableStaticAnalysis/SourceTransformation/Transformations/CppBoundedBuffers.cpp
+246-1clang/unittests/ScalableStaticAnalysis/SourceTransformation/CppBoundedBuffersTest.cpp
+9-0clang/lib/ScalableStaticAnalysis/SourceTransformation/CMakeLists.txt
+7-0llvm/utils/gn/secondary/clang/lib/ScalableStaticAnalysis/SourceTransformation/BUILD.gn
+707-64 files

OpenBSD/src 6DqafLwusr.sbin/smtpd smtpd-api.h smtpctl.c

   add a TLS flag to envelopes

   make a configuration like

        match ... tls ... action foobar

   actually work.

   diff from Johan Hattne with a small smtpctl.c tweak by me.
   okay kirill@
VersionDeltaFile
1.49+6-3usr.sbin/smtpd/ruleset.c
1.53+8-1usr.sbin/smtpd/envelope.c
1.451+3-1usr.sbin/smtpd/smtp_session.c
1.38+2-1usr.sbin/smtpd/smtpd-api.h
1.179+2-1usr.sbin/smtpd/smtpctl.c
+21-75 files

LLVM/project efe61a2clang/include/clang/ScalableStaticAnalysis/Analyses/EntityPointerLevel EntityPointerLevel.h, clang/include/clang/ScalableStaticAnalysis/Analyses/PointerFlow PointerFlowPairs.h

[SSAF][PointerFlow] Drop unused TUSummaryExtractor param from translateDeclPointerLevel

TUSummaryExtractor is only needed to mint EntityIds when building an
EntityPointerLevel; translateDeclPointerLevel just walks the Expr and
returns raw DeclPointerLevels, so it never touched Extractor.

This is the second patch the radar below depends on:
rdar://187125348
DeltaFile
+24-20clang/lib/ScalableStaticAnalysis/Analyses/EntityPointerLevel/EntityPointerLevel.cpp
+2-3clang/include/clang/ScalableStaticAnalysis/Analyses/EntityPointerLevel/EntityPointerLevel.h
+2-2clang/lib/ScalableStaticAnalysis/Analyses/PointerFlow/PointerFlowExtractor.cpp
+2-0clang/include/clang/ScalableStaticAnalysis/Analyses/PointerFlow/PointerFlowPairs.h
+30-254 files

LLVM/project 58b7d98clang/lib/ScalableStaticAnalysis/Analyses/PointerFlow PointerFlowExtractor.cpp

fix clang-format
DeltaFile
+1-2clang/lib/ScalableStaticAnalysis/Analyses/PointerFlow/PointerFlowExtractor.cpp
+1-21 files

LLVM/project a73dac5clang/include/clang/ScalableStaticAnalysis/Analyses/PointerFlow PointerFlowPairs.h, clang/lib/ScalableStaticAnalysis/Analyses SSAFAnalysesCommon.h

[SSAF][PointerFlow] Factor out and make the pointer-flow matching reusable

The PointerFlowExtractor matches AST nodes representing pointer-flows
and converts them to entity-based data structures directly. This
commit divides this procedure into two steps: 1) match and represent
AST nodes as PointerFlowPairs; 2) convert PointerFlowPairs to
entity-based edges. Therefore, other SSAF tools may use
PointerFlowPairs.

The refactoring also improves coverage: it separates pointer-type
checking from structural matching, so structural matching alone now
discovers cases that were previously missed due to overly aggressive
type checking (e.g. a record-typed call argument or return value
initialized with a braced-init-list).

Along the way, this also fixes a bug for unnamed bit-fields.

First patch for
rdar://187125348
DeltaFile
+433-0clang/unittests/ScalableStaticAnalysis/Analyses/PointerFlow/PointerFlowPairsTest.cpp
+300-0clang/lib/ScalableStaticAnalysis/Analyses/PointerFlow/PointerFlowPairs.cpp
+67-232clang/lib/ScalableStaticAnalysis/Analyses/PointerFlow/PointerFlowExtractor.cpp
+122-0clang/include/clang/ScalableStaticAnalysis/Analyses/PointerFlow/PointerFlowPairs.h
+7-1clang/lib/ScalableStaticAnalysis/Analyses/SSAFAnalysesCommon.h
+1-0llvm/utils/gn/secondary/clang/unittests/ScalableStaticAnalysis/BUILD.gn
+930-2333 files not shown
+933-2339 files

FreeBSD/src a22eb75sys/dev/tpm tpm_tis_core.c

tpm_tis: Quiesce interrupts before registering a handler

The current interrupt path uses the IRQ resource value directly as the
LPC SIRQ selector in TPM_INT_VECTOR and already restricts it to 1 through
15. This is a driver limitation: a parent interrupt number need not equal
an LPC SIRQ channel, and SPI TPMs can use a separate parallel interrupt.

On the reported system with ACPI IRQ 45, the existing range check runs
after handler registration and returns before disabling firmware interrupt
delivery. This can leave a polling device with a handler on an asserted
source.

Disable and verify interrupt delivery before registering a handler or
starting common TPM services. Preserve the existing range policy, using
polling without registering a handler for routes rejected by that check,
and release their IRQ resources. Keep a failed setup's potentially stale
output cookie out of the device state; the interrupt framework may
already have removed that handler.


    [19 lines not shown]
DeltaFile
+90-23sys/dev/tpm/tpm_tis_core.c
+90-231 files

LLVM/project 0485ad7clang/lib/CodeGen CodeGenModule.cpp, clang/test/CodeGen thread-model.c

clang: Emit the "thread-model" module flag (#223156)
DeltaFile
+11-0clang/test/CodeGen/thread-model.c
+9-0clang/lib/CodeGen/CodeGenModule.cpp
+20-02 files

OpenBSD/src jLQkRzsusr.bin/mandoc man.cgi.8 cgi.c

   Support including a HTML snippet from an optional file head.html
   right before the end of the <head> element.
   For example, man.voidlinux.org uses this to include a second,
   site-specific CSS file such that mandoc.css can be used unchanged.

   Based on a patch from Abigail G <dev at placeviolette.net>
   slightly tweaked by me to open the file early.
VersionDeltaFile
1.126+8-7usr.bin/mandoc/cgi.c
1.24+8-2usr.bin/mandoc/man.cgi.8
+16-92 files

LLVM/project 667efaellvm/lib/Transforms/InstCombine InstCombineCompares.cpp, llvm/test/Transforms/InstCombine icmp-rotate.ll

[InstCombine] Fix fold of comparison of rotates (#223263)

rotate(X, AmtX) == rotate(Y, AmtY) -> rotate(X, AmtX - AmtY) == Y

This fold is usually valid, but implicitly assumed that the bit width
was a power of two. This is now checked and the transform doesn't fire
if the bit width isn't a power of two.

Fixes https://github.com/llvm/llvm-project/issues/223262
DeltaFile
+12-6llvm/lib/Transforms/InstCombine/InstCombineCompares.cpp
+14-0llvm/test/Transforms/InstCombine/icmp-rotate.ll
+26-62 files

OpenBSD/ports qQ5d1b0security/vaultwarden Makefile crates.inc

   Update to vaultwarden-1.37.3

   Changes: https://github.com/dani-garcia/vaultwarden/releases/tag/1.37.3
VersionDeltaFile
1.40+278-258security/vaultwarden/distinfo
1.36+138-128security/vaultwarden/crates.inc
1.60+1-1security/vaultwarden/Makefile
+417-3873 files

Illumos/gate dcfd6a5usr/src/cmd/sunpc/other unix2dos.c dos2unix.c, usr/src/man/man1 dos2unix.1 unix2dos.1

15262 Files are optional for dos2unix/unix2dos
Reviewed by: Bill Sommerfeld <sommerfeld at hamachi.org>
Reviewed by: Toomas Soome <tsoome at me.com>
Approved by: Gordon Ross <gordon.w.ross at gmail.com>
DeltaFile
+9-30usr/src/man/man1/unix2dos.1
+8-29usr/src/man/man1/dos2unix.1
+4-1usr/src/cmd/sunpc/other/dos2unix.c
+3-1usr/src/cmd/sunpc/other/unix2dos.c
+24-614 files

LLVM/project 86858declang/test/Headers __clang_hip_math.hip, llvm/lib/Analysis ValueTracking.cpp

[ValueTracking] Propagate non-negativity through fptosi (#217868)

Fixes #217442

`fptosi` is poison when the rounded value does not fit in the result
type, so `computeKnownBits` can assume the conversion rounds towards
zero without wrapping. Negative subnormals and negative zero always
round to 0, so only sources known to never be a negative normal or
negative infinity (i.e. values <= -1.0) can produce a negative result.

This lets InstCombine fold `(int)fabs(x) < 0` to `false`, matching GCC,
and also benefits other magnitude-clamping intrinsics such as sqrt.
DeltaFile
+704-704clang/test/Headers/__clang_hip_math.hip
+65-0llvm/test/Transforms/InstCombine/fabs.ll
+21-0llvm/unittests/Analysis/ValueTrackingTest.cpp
+13-1llvm/lib/Analysis/ValueTracking.cpp
+14-0llvm/test/Transforms/InstCombine/sitofp.ll
+3-3llvm/test/CodeGen/AMDGPU/amdgpu-simplify-libcall-pow.ll
+820-7081 files not shown
+825-7087 files

LLVM/project 8e23b6dllvm/lib/Target/AMDGPU GCNCreateVOPD.cpp GCNVOPDUtils.cpp

[NFC][AMDGPU] Fix clang-tidy warnings in VOPD related files (#223261)
DeltaFile
+7-7llvm/lib/Target/AMDGPU/GCNVOPDUtils.cpp
+5-3llvm/lib/Target/AMDGPU/GCNCreateVOPD.cpp
+12-102 files

LLVM/project cba24d6llvm/lib/Transforms/Vectorize VPlanTransforms.cpp

[VPlan] Generalize folding IV increment into phi start value (NFC). (#223260)

simplifyRecipe folds

  X    = phi(0, IVInc)
  IVInc = X + Step
  Def   = IVInc + Y

into a phi starting at Y, but only if Y is a live-in. Also allow values
defined in the block the phi's start value is coming from, which is
where the value conservatively has to be available.

NFC today, but preparation for modeling the full epilogue skeleton in
VPlan.
DeltaFile
+20-13llvm/lib/Transforms/Vectorize/VPlanTransforms.cpp
+20-131 files

LLVM/project d44791dllvm/lib/Target/AMDGPU SIInstructions.td SIISelLowering.cpp, llvm/test/CodeGen/AMDGPU llvm.amdgcn.sched.barrier.ll

[AMDGPU] IGLP: Sanitize user schedule hints (#221256)

Fixes the following ICE:
```cpp
extern __shared__ int lds[];

__global__
void kern_ice() {
    auto _ = lds[threadIdx.x];
    __builtin_amdgcn_sched_barrier(~0x380); // Allow all except DS instructions
}
```

See: https://godbolt.org/z/oGfT1TTa4
DeltaFile
+0-22llvm/lib/Target/AMDGPU/AMDGPUIGroupLP.cpp
+22-0llvm/lib/Target/AMDGPU/AMDGPUIGroupLP.h
+6-0llvm/lib/Target/AMDGPU/SIISelLowering.cpp
+2-0llvm/test/CodeGen/AMDGPU/llvm.amdgcn.sched.barrier.ll
+2-0llvm/lib/Target/AMDGPU/SIInstructions.td
+32-225 files